audit

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package audit provides a client for the Doppler API's audit endpoints.

API-Docs: https://docs.doppler.com/reference/audit-api-reference

Example:

    // Fetch audit logs for the current workplace
		logs, _, err := audit.WorkplaceGet(context.Background(), &doppler.AuditWorkplaceGetOptions{})
		if err != nil {
			log.Fatal(err)
		}

		fmt.Println(logs)

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WorkplaceGet

WorkplaceGet returns an audit log for a workplace using the default client.

func WorkplaceUserGet

WorkplaceUserGet returns an audit log for a workplace user using the default client.

func WorkplaceUserList

WorkplaceUserList returns a list of audit logs for workplace users using the default client.

Types

type Client

type Client struct {
	Backend doppler.Backend
	Key     string
}

Client is the client used to invoke /v3/configs/config/secrets APIs.

func Default

func Default() *Client

Default returns a new client based on the SDK's default backend and API key.

func (Client) WorkplaceGet

WorkplaceGet returns an audit log for a workplace.

func (Client) WorkplaceUserGet

WorkplaceUserGet returns an audit log for a workplace user.

func (Client) WorkplaceUserList

WorkplaceUserList returns a list of audit logs for workplace users.

Jump to