Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IssueLease ¶
func IssueLease(ctx context.Context, opts *doppler.DynamicSecretIssueLeaseOptions) (doppler.APIResponse, error)
IssueLease issues a lease for a dynamic secret using the default client.
func RevokeLease ¶
func RevokeLease(ctx context.Context, opts *doppler.DynamicSecretRevokeLeaseOptions) (doppler.APIResponse, error)
RevokeLease revokes a lease for a dynamic secret using the default client.
Types ¶
type Client ¶
Client is the client used to invoke /configs/config/dynamic_secrets/dynamic_secret APIs.
func Default ¶
func Default() *Client
Default returns a new client based on the SDK's default backend and API key.
func (Client) IssueLease ¶
func (c Client) IssueLease(ctx context.Context, opts *doppler.DynamicSecretIssueLeaseOptions) (doppler.APIResponse, error)
IssueLease issues a lease for a dynamic secret.
func (Client) RevokeLease ¶
func (c Client) RevokeLease(ctx context.Context, opts *doppler.DynamicSecretRevokeLeaseOptions) (doppler.APIResponse, error)
RevokeLease revokes a lease for a dynamic secret.
Click to show internal directories.
Click to hide internal directories.