secret

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package secret provides a client for the Doppler API's secret endpoints.

API-Docs: https://docs.doppler.com/reference/config-secret-list

Example:

  // Download secrets in docker format.
	secrets, _, err := secret.Download(context.Background(), &doppler.SecretDownloadOptions{
		Project: "your-project",
		Config:  "your-config",
		Format:  stringPointer("docker"),
	})
	if err != nil {
		log.Fatal(err)
	}

	fmt.Println(secrets)

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Download

Download downloads a config secret using the default client.

func Get

Get returns a config secret and its respective info using the default client.

func List

List returns a list of config secrets using the default client.

func Update

Update updates a config secret using the default client.

Types

type Client

type Client struct {
	Backend doppler.Backend
	Key     string
}

Client is the client used to invoke /v3/configs/config/secrets APIs.

func Default

func Default() *Client

Default returns a new client based on the SDK's default backend and API key.

func (Client) Download

Download downloads a config secret.

func (Client) Get

Get returns a config secret and its respective info.

func (Client) List

List returns a list of config secrets.

func (Client) Update

Update updates a config secret.

Jump to